==> jupyterlite_pyodide_kernel-0.0.5.tar.gz: jupyterlite_pyodide_kernel-0.0.5/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.0.5

([Full Changelog](https://github.com/jupyterlite/pyodide-kernel/compare/@jupyterlite/pyodide-kernel-extension@0.0.4...61c29231d8bb9b32cf1bfde7d60e9f0971901341))

### Maintenance and upkeep improvements

- Depend on `jupyterlite-core >=0.1.0b19` [#30](https://github.com/jupyterlite/pyodide-kernel/pull/30) ([@jtpio](https://github.com/jtpio))
- Releaser: support bumping versions with `next` as the spec [#26](https://github.com/jupyterlite/pyodide-kernel/pull/26) ([@jtpio](https://github.com/jtpio))
- Install `lint` extra on Gitpod [#25](https://github.com/jupyterlite/pyodide-kernel/pull/25) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/pyodide-kernel/graphs/contributors?from=2023-03-10&to=2023-03-15&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Agithub-actions+updated%3A2023-03-10..2023-03-15&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Ajtpio+updated%3A2023-03-10..2023-03-15&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.0.4

([Full Changelog](https://github.com/jupyterlite/pyodide-kernel/compare/@jupyterlite/pyodide-kernel-extension@0.0.3...794b132092f7965becd018e00b9f188dc182963a))

### Maintenance and upkeep improvements

- Depend on `jupyterlite-core` [#23](https://github.com/jupyterlite/pyodide-kernel/pull/23) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/pyodide-kernel/graphs/contributors?from=2023-03-10&to=2023-03-10&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Abollwyvl+updated%3A2023-03-10..2023-03-10&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Agithub-actions+updated%3A2023-03-10..2023-03-10&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Ajtpio+updated%3A2023-03-10..2023-03-10&type=Issues)

## 0.0.3

([Full Changelog](https://github.com/jupyterlite/pyodide-kernel/compare/@jupyterlite/pyodide-kernel-extension@0.0.2...ea540d9568afaca516b6ac85b6dc29eaf20ce917))

### Maintenance and upkeep improvements

- Restore more python tools and tests [#19](https://github.com/jupyterlite/pyodide-kernel/pull/19) ([@bollwyvl](https://github.com/bollwyvl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/pyodide-kernel/graphs/contributors?from=2023-03-06&to=2023-03-10&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Abollwyvl+updated%3A2023-03-06..2023-03-10&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Agithub-actions+updated%3A2023-03-06..2023-03-10&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Ajtpio+updated%3A2023-03-06..2023-03-10&type=Issues)

## 0.0.2

([Full Changelog](https://github.com/jupyterlite/pyodide-kernel/compare/first-commit...96fe906b11689daff7c0737a0d35cb25d54d6cc9))

### Maintenance and upkeep improvements

- Fix direct dependency [#17](https://github.com/jupyterlite/pyodide-kernel/pull/17) ([@jtpio](https://github.com/jtpio))
- Releaser fixes [#16](https://github.com/jupyterlite/pyodide-kernel/pull/16) ([@jtpio](https://github.com/jtpio))
- Update Jupyter Releaser hooks [#13](https://github.com/jupyterlite/pyodide-kernel/pull/13) ([@jtpio](https://github.com/jtpio))
- Add Gitpod config [#12](https://github.com/jupyterlite/pyodide-kernel/pull/12) ([@jtpio](https://github.com/jtpio))
- Remove Binder files [#7](https://github.com/jupyterlite/pyodide-kernel/pull/7) ([@jtpio](https://github.com/jtpio))
- Add releaser workflows to the repo [#4](https://github.com/jupyterlite/pyodide-kernel/pull/4) ([@jtpio](https://github.com/jtpio))
- Add the Pyodide kernel from the JupyterLite repository [#2](https://github.com/jupyterlite/pyodide-kernel/pull/2) ([@jtpio](https://github.com/jtpio))
- Bootstrap the repo from the cookiecutter [#1](https://github.com/jupyterlite/pyodide-kernel/pull/1) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Minor README edits [#11](https://github.com/jupyterlite/pyodide-kernel/pull/11) ([@jtpio](https://github.com/jtpio))
- Add ReadTheDocs preview CI workflow [#10](https://github.com/jupyterlite/pyodide-kernel/pull/10) ([@jtpio](https://github.com/jtpio))
- Add files for ReadTheDocs, enable Python tests, maintenance [#8](https://github.com/jupyterlite/pyodide-kernel/pull/8) ([@bollwyvl](https://github.com/bollwyvl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/pyodide-kernel/graphs/contributors?from=2022-12-01&to=2023-03-06&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Abollwyvl+updated%3A2022-12-01..2023-03-06&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Agithub-actions+updated%3A2022-12-01..2023-03-06&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Ajtpio+updated%3A2022-12-01..2023-03-06&type=Issues)

==> jupyterlite_pyodide_kernel-0.0.6.tar.gz: jupyterlite_pyodide_kernel-0.0.6/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.0.6

([Full Changelog](https://github.com/jupyterlite/pyodide-kernel/compare/@jupyterlite/pyodide-kernel-extension@0.0.5...55d8df5291d586255b5cd3e92c1d54bff4c32c8f))

### Maintenance and upkeep improvements

- Update to Pyodide 0.23, update mocks [#39](https://github.com/jupyterlite/pyodide-kernel/pull/39) ([@bollwyvl](https://github.com/bollwyvl))

### Documentation improvements

- Update instructions in the README [#31](https://github.com/jupyterlite/pyodide-kernel/pull/31) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/pyodide-kernel/graphs/contributors?from=2023-03-15&to=2023-03-31&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Abollwyvl+updated%3A2023-03-15..2023-03-31&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Agithub-actions+updated%3A2023-03-15..2023-03-31&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Ajtpio+updated%3A2023-03-15..2023-03-31&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.0.5

([Full Changelog](https://github.com/jupyterlite/pyodide-kernel/compare/@jupyterlite/pyodide-kernel-extension@0.0.4...61c29231d8bb9b32cf1bfde7d60e9f0971901341))

### Maintenance and upkeep improvements

- Depend on `jupyterlite-core >=0.1.0b19` [#30](https://github.com/jupyterlite/pyodide-kernel/pull/30) ([@jtpio](https://github.com/jtpio))
- Releaser: support bumping versions with `next` as the spec [#26](https://github.com/jupyterlite/pyodide-kernel/pull/26) ([@jtpio](https://github.com/jtpio))
- Install `lint` extra on Gitpod [#25](https://github.com/jupyterlite/pyodide-kernel/pull/25) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/pyodide-kernel/graphs/contributors?from=2023-03-10&to=2023-03-15&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Agithub-actions+updated%3A2023-03-10..2023-03-15&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Ajtpio+updated%3A2023-03-10..2023-03-15&type=Issues)

## 0.0.4

([Full Changelog](https://github.com/jupyterlite/pyodide-kernel/compare/@jupyterlite/pyodide-kernel-extension@0.0.3...794b132092f7965becd018e00b9f188dc182963a))

### Maintenance and upkeep improvements

- Depend on `jupyterlite-core` [#23](https://github.com/jupyterlite/pyodide-kernel/pull/23) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/pyodide-kernel/graphs/contributors?from=2023-03-10&to=2023-03-10&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Abollwyvl+updated%3A2023-03-10..2023-03-10&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Agithub-actions+updated%3A2023-03-10..2023-03-10&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Ajtpio+updated%3A2023-03-10..2023-03-10&type=Issues)

## 0.0.3

([Full Changelog](https://github.com/jupyterlite/pyodide-kernel/compare/@jupyterlite/pyodide-kernel-extension@0.0.2...ea540d9568afaca516b6ac85b6dc29eaf20ce917))

### Maintenance and upkeep improvements

- Restore more python tools and tests [#19](https://github.com/jupyterlite/pyodide-kernel/pull/19) ([@bollwyvl](https://github.com/bollwyvl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/pyodide-kernel/graphs/contributors?from=2023-03-06&to=2023-03-10&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Abollwyvl+updated%3A2023-03-06..2023-03-10&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Agithub-actions+updated%3A2023-03-06..2023-03-10&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Ajtpio+updated%3A2023-03-06..2023-03-10&type=Issues)

## 0.0.2

([Full Changelog](https://github.com/jupyterlite/pyodide-kernel/compare/first-commit...96fe906b11689daff7c0737a0d35cb25d54d6cc9))

### Maintenance and upkeep improvements

- Fix direct dependency [#17](https://github.com/jupyterlite/pyodide-kernel/pull/17) ([@jtpio](https://github.com/jtpio))
- Releaser fixes [#16](https://github.com/jupyterlite/pyodide-kernel/pull/16) ([@jtpio](https://github.com/jtpio))
- Update Jupyter Releaser hooks [#13](https://github.com/jupyterlite/pyodide-kernel/pull/13) ([@jtpio](https://github.com/jtpio))
- Add Gitpod config [#12](https://github.com/jupyterlite/pyodide-kernel/pull/12) ([@jtpio](https://github.com/jtpio))
- Remove Binder files [#7](https://github.com/jupyterlite/pyodide-kernel/pull/7) ([@jtpio](https://github.com/jtpio))
- Add releaser workflows to the repo [#4](https://github.com/jupyterlite/pyodide-kernel/pull/4) ([@jtpio](https://github.com/jtpio))
- Add the Pyodide kernel from the JupyterLite repository [#2](https://github.com/jupyterlite/pyodide-kernel/pull/2) ([@jtpio](https://github.com/jtpio))
- Bootstrap the repo from the cookiecutter [#1](https://github.com/jupyterlite/pyodide-kernel/pull/1) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Minor README edits [#11](https://github.com/jupyterlite/pyodide-kernel/pull/11) ([@jtpio](https://github.com/jtpio))
- Add ReadTheDocs preview CI workflow [#10](https://github.com/jupyterlite/pyodide-kernel/pull/10) ([@jtpio](https://github.com/jtpio))
- Add files for ReadTheDocs, enable Python tests, maintenance [#8](https://github.com/jupyterlite/pyodide-kernel/pull/8) ([@bollwyvl](https://github.com/bollwyvl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/pyodide-kernel/graphs/contributors?from=2022-12-01&to=2023-03-06&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Abollwyvl+updated%3A2022-12-01..2023-03-06&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Agithub-actions+updated%3A2022-12-01..2023-03-06&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fpyodide-kernel+involves%3Ajtpio+updated%3A2022-12-01..2023-03-06&type=Issues)
